//do-file for "Critical issues"
//use Critical_issues.dta


//Transformations

hist GDPperCapita, normal					//produces histogram displaying normal curve
summarize GDPperCapita, detail				//detailed summary statistics

generate transformedGDP = GDPperCapita^2 	//reduces negative skew
generate transformedGDP = GDPperCapita^1  	//same as original variable
generate transformedGDP = GDPperCapita^-1   //reduces positive skew
generate lnGDP = ln(GDPperCapita)			//log transformation, reduces positive skew

summarize lnGDP, detail						//detailed summary statistics

generate FDItest= FDI + 84662791823			//log transformation of variable with zero or negative numbers
generate lnFDI = ln(FDItest)				

generate FDIreverse = 340065000001 - FDI	// preparing negatively skewed variable for log transformation by reversing it


//Weighting cases
//use WeightingP.dta

tab dweight
regress Political_Trust woman age unemployed eduyrs [pweight=dweight]	// regression using the pweight option

svyset _n [pweight = dweight]									//using the survey command option
svy: regress Political_Trust woman age unemployed eduyrs		//weighted regression within the survey command option

//use WeightingA

summarize GDPperCapita [aweight = populalation]			//summary statistics using the aweight command

regress GDPperCapita polity2 [aweight=population]		//regression using the aweight command



//Robust regression
//use Robust_regression.dta

regress GDPperCapita lnFDI				//OLS regression
predict GDPhat1							//saving predicted values from OLS regression
label variable GDPhat1 "OLS regression" 
predict res, residual					//predicting residuals from OLS regression
hist res								//histogram of residuals
rvfplot									//produces rvfplot to check for heteroskedasticity 
graph twoway (scatter GDPperCapita lnFDI, mlabel(ccode)) (lfit GDPperCapita lnFDI, mlabel(ccode))		//graphing linear relationship, including country labels
predict cooksd, cooksd
sort cooksd
browse ccode cooksd						//investigating Cook's distance values

rreg GDPperCapita lnFDI					//robust regression

predict GDPhat2							//saving predicted values from robust regression
label variable GDPhat2 robust regression
graph twoway scatter GDPperCapita GDPhat1 GDPhat2 lnFDI, mlabel(ccode)		//graphing OLS- and robust regression lines
	
	

//Missing data
//use Missing_data.dta


generate trstep_miss = missing(trstep)	//generating a new variable denoting whether respondents are missing on the original variable

summarize age woman trstprl lrscale if trstep_miss==0
summarize age woman trstprl lrscale if trstep_miss==1	//comparing the means on other variables for those missing and not missing

tab prtvtgb, missing			//tabulating variable
generate dummy_LibDem=0
replace dummy_LibDem=1 if prtvtgb==3	//generating dummy variable

generate dummy_miss=0					
replace dummy_miss=1 if prtvtgb==.		//generating dummy variable for missing values

generate new_trstep = trstep
summarize trstep
replace new_trstep = 3.297199 if trstep==.		//replacing missing with mean values
regress happy woman age new_trstep trstep_miss	//regression using dummy variable adjustment

sum trstep
generate mean_trstep = trstep
replace mean_trstep = 3.297199 if trstep==.		//replacing missing with mean values (same procedure as above)

regress trstep ppltrst freehms imsmetn woman age
predict Y
generate predict_trstep = trstep
replace predict_trstep = Y if trstep==.			//replacing missing with regression predicted values


regress happy trstep tvtot ppltrst freehms imsmetn woman age	//OLS regression

misstable summarize						//summary statistics for the dataset

mi set mlong					//set the data ready for marginal long style
mi register imputed trstep		//register variable for imputation
mi register regular happy tvtot ppltrst freehms imsmetn woman age pplfair trstprl imdfetn		//register variables to be used for imputing the above variable
mi impute regress trstep happy tvtot ppltrst freehms imsmetn woman age pplfair trstprl imdfetn, add(20) rseed(1234) force	//imputing the values using regress option
mi xeq 0 1 20: summarize trstep	// summarizing original variable, as well as first and twentieth impuation

mi impute pmm trstep happy tvtot ppltrst freehms imsmetn woman age pplfair trstprl imdfetn, add(20) rseed(1234) knn(10) force	//imputing the values using pmm option
mi xeq 0 1 20: summarize trstep	// summarizing original variable, as well as first and twentieth impuation

mi estimate: regress happy trstep tvtot ppltrst freehms imsmetn woman age  //performing the pooled regression estimation


//clear data, and open Missing_data.dta again

mi set mlong		//set the data ready for marginal long style
mi register imputed lrscale trstep //register variables for imputation
mi register regular happy tvtot ppltrst freehms imsmetn woman age pplfair trstprl imdfetn	//register variables to be used for imputing the above variables
mi impute mvn trstep lrscale = happy tvtot ppltrst freehms imsmetn woman age pplfair trstprl imdfetn, add(20) rseed(1234) force		//imputing the values using mvn option
mi xeq 0 1 20: summarize lrscale trstep		// summarizing original variables, as well as first and twentieth impuation


mi estimate: regress happy lrscale trstep tvtot ppltrst freehms imsmetn woman age	//performing the pooled regression estimation













